@@ -4,7 +4,10 @@ use std::slice;
 #[multiversion::multiversion]
 #[clone(target = "[x86|x86_64]+avx2")]
 #[clone(target = "wasm32+simd128")]
-#[clone(target = "aarch64+neon")]
+#[cfg_attr(
+    all(target_arch = "aarch64", feature = "aarch64"),
+    clone(target = "aarch64+neon")
+)]
 pub unsafe fn generic(left: *const u8, right: *const u8, n: usize) -> bool {
     slice::from_raw_parts(left, n) == slice::from_raw_parts(right, n)
 }
@@ -13,7 +16,10 @@ pub unsafe fn generic(left: *const u8, right: *const u8, n: usize) -> bool {
 #[multiversion::multiversion]
 #[clone(target = "[x86|x86_64]+avx2")]
 #[clone(target = "wasm32+simd128")]
-#[clone(target = "aarch64+neon")]
+#[cfg_attr(
+    all(target_arch = "aarch64", feature = "aarch64"),
+    clone(target = "aarch64+neon")
+)]
 pub unsafe fn specialized<const N: usize>(left: *const u8, right: *const u8) -> bool {
     slice::from_raw_parts(left, N) == slice::from_raw_parts(right, N)
 }
